@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@ class GravatarCacheTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit GravatarCacheTest(QObject *parent = Q_NULLPTR);
+    explicit GravatarCacheTest(QObject *parent = nullptr);
     ~GravatarCacheTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
